//+------------------------------------------------------------------+
//|                                                         SRDC.mq4 |
//| Concept: Setup pending orders on last days high and low          |
//+------------------------------------------------------------------+

//---- input parameters
extern int  BORDER          =   5,  // pips we add to the high and low to get entry price
            START_TIME      =  1;  // setup positions at this time of day

//---- order parameters
extern double    LOTS       = 0.1;  // amount of lots to trade
extern int       STOPLOSS   =   20,  // max loss
                 TAKEPROFIT =   60,  // max profit
                 MOVE_SL_AT =  35,  // if an order reaches this profit level...
                 MOVE_SL_TO =   5,  // ...adjust SL to this profit level
     CLOSE_AFTER_N_CANDLES  =   1,  // orders are closed n candles after opening - no matter what
                 TRAILSTOP  =   0,  // adjust stoploss if new profit levels are reached
                 SLIPPAGE   =   0;  // max slippage on order open and close

//----
int ticket1 = -1, // long position
    ticket2 = -1; // short position

//+------------------------------------------------------------------+
//| Select an order by ticket and check if (pending) order
//| has triggered but was not yet closed.
//+------------------------------------------------------------------+
bool IsOrderOpen(int ticket)
{
   return(OrderSelect(ticket,SELECT_BY_TICKET)
      && (OrderType()==OP_BUY || OrderType()==OP_SELL)
      &&  OrderCloseTime()==0);
}

//+------------------------------------------------------------------+
//| expert start function                                            |
//+------------------------------------------------------------------+
int start()
{
//----
// check trailing stop
   if(TRAILSTOP != 0)
   {
      if(IsOrderOpen(ticket1))
         if(Bid-OrderOpenPrice() > TRAILSTOP*Point && OrderStopLoss() < Bid-TRAILSTOP*Point)
            OrderModify(OrderTicket(),OrderOpenPrice(),Bid-TRAILSTOP*Point,OrderTakeProfit(),OrderExpiration());

      if(IsOrderOpen(ticket2))
         if(OrderOpenPrice()-Ask > TRAILSTOP*Point && OrderStopLoss() > Ask+TRAILSTOP*Point)
            OrderModify(OrderTicket(),OrderOpenPrice(),Ask+TRAILSTOP*Point,OrderTakeProfit(),OrderExpiration());
   }

//----
// move sl to break even or slight profit
   if(MOVE_SL_AT != 0)
   {
      if(IsOrderOpen(ticket1))
         if(Bid-OrderOpenPrice() > MOVE_SL_AT*Point && OrderStopLoss() < OrderOpenPrice()+MOVE_SL_TO*Point)
            OrderModify(OrderTicket(),OrderOpenPrice(),OrderOpenPrice()+MOVE_SL_TO*Point,OrderTakeProfit(),OrderExpiration());

      if(IsOrderOpen(ticket2))
         if(OrderOpenPrice()-Ask > MOVE_SL_AT*Point && OrderStopLoss() > OrderOpenPrice()-MOVE_SL_TO*Point)
            OrderModify(OrderTicket(),OrderOpenPrice(),OrderOpenPrice()-MOVE_SL_TO*Point,OrderTakeProfit(),OrderExpiration());
   }

//----
// Continue only once every new candle
  static datetime lastCandle = 0;

   if(CurTime()!=Time[0] || Time[0]==lastCandle)
      return(0);

   lastCandle = Time[0];

//----
// close orders at n candles after entry
   if(CLOSE_AFTER_N_CANDLES!=0)
   {
      if(IsOrderOpen(ticket1) && CurTime()-OrderOpenTime() > CLOSE_AFTER_N_CANDLES*Period()*60)
         OrderClose(ticket1, LOTS, Bid, 1);

      if(IsOrderOpen(ticket2) && CurTime()-OrderOpenTime() > CLOSE_AFTER_N_CANDLES*Period()*60)
         OrderClose(ticket2, LOTS, Ask, 1);
   }

//----
// setup new pending orders
   if(TimeHour(CurTime())==START_TIME && TimeMinute(CurTime())==0)
   {
   //----
   // close any remaining orders
      if(IsOrderOpen(ticket1))
         OrderClose(ticket1, LOTS, Bid, SLIPPAGE);

      if(IsOrderOpen(ticket2))
         OrderClose(ticket2, LOTS, Ask, SLIPPAGE);
         
      if(IsOrderOpen(ticket1) || IsOrderOpen(ticket2))
      {
         Print("Warning: could not close orders");
         return(1);
      }

   //----
   // Collect highs and lows
      /*double high = 0,
             low  = 99999;

      for (int i = 0; i < PERIOD_D1/Period(); i++)
      {
         if(high < High[i])
            high = High[i];
         if(low > Low[i])
            low = Low[i];
      }
     */
     double high = iHigh(NULL,PERIOD_D1,1);
     double low  = iLow(NULL,PERIOD_D1,1);
   //----
   // Order parameter
      double spread = Ask-Bid,
             buy    = high + spread + BORDER*Point,
             sell   = low  - spread - BORDER*Point;
      int    op_buy = OP_BUYSTOP,
             op_sell= OP_SELLSTOP;

   //----
   // SL and TP targets
      double buy_sl = buy - STOPLOSS*Point,
             sell_sl= sell+ STOPLOSS*Point,
             buy_tp = buy + TAKEPROFIT*Point,
             sell_tp= sell- TAKEPROFIT*Point;
      
      // Don't use stoploss?
      if(STOPLOSS==0)
      {
         buy_sl = 0;
         sell_sl= 0;
      }

      // Don't use takeprofit?
      if(TAKEPROFIT==0)
      {
         buy_tp = 0;
         sell_tp= 0;
      }

      ticket1 = OrderSend(Symbol(), OP_BUYSTOP, LOTS, buy, SLIPPAGE, buy_sl, buy_tp, "SRDC EA", 0, Time[0]+60*PERIOD_D1, Blue);
      ticket2 = OrderSend(Symbol(), OP_SELLSTOP,LOTS, sell,SLIPPAGE, sell_sl,sell_tp,"SRDC EA", 0, Time[0]+60*PERIOD_D1, Red);
   }

//----
   return(0);
}
//+------------------------------------------------------------------+

